<?php
 
abstract class baseController {
	protected $registry;

	function __construct($registry) {
		$this->registry = $registry;
	}
	
	abstract function index();
}

class Registry {
	private $vars = array();

	public function __set($index, $value) {
		$this->vars[$index] = $value;
	}

	public function __get($index) {
		return $this->vars[$index];
	}
}

class router {
	private $registry;
	private $controllerPath;
	private $modelPath;
	private $args = array();
	public $file;
	public $controller;
	public $action; 

	function __construct($registry) {
	    $this->registry = $registry;
	}
	
	public function debug($flag) {
		ini_set('display_errors', 'On');
		error_reporting($flag);
	}
	
	public function redirect($url,$msg = "") { 
		if ($msg != "") {
			$session =& JFactory::getSession();
			$session->set('application.message', $msg);
		}
		header( 'HTTP/1.1 301 Moved Permanently' );
		header( 'Location: ' . $url );
		//echo'<meta HTTP-EQUIV="refresh" CONTENT="'.$interval.';URL='.$url.'">'; 
	}

	public function setPath($path,$type) {
		if ($type == "Controller") {
			if (is_dir($path) == false) throw new Exception ('Invalid controller path: `' . $path . '`');
			$this->controllerPath = $path;
		}
		else if ($type == "Model") {
			if (is_dir($path) == false) throw new Exception ('Invalid controller path: `' . $path . '`');
			$this->modelPath = $path;
		}
	}

	public function loader() {
		$this->getController();
		if (is_readable($this->file) == false)
		{
			$this->file = $this->controllerPath.'/error404.php';
	        $this->controller = 'error404';
		}
		include $this->file;
		$class = $this->controller . 'Control';
		$controller = new $class($this->registry);
		if (is_callable(array($controller, $this->action)) == false) $action = 'index';
		else $action = $this->action;
		$controller->$action();
	}

	private function getController() {
		$this->controller = (empty($_GET['section'])) ? '' : $_GET['section'];
		$this->action = (empty($_GET['task'])) ? '' : $_GET['task'];
		if (empty($this->controller)) $this->controller = 'index';
		if (empty($this->action)) $this->action = 'index';
	
		$this->file = $this->controllerPath .'/'. $this->controller . 'Control.php';
	}
	
	public function getModel($class,$argues="") {
		if (file_exists($this->modelPath .'/'.strtolower($class).'.class.php') == false) return false;
		include($this->modelPath .'/'.strtolower($class).'.class.php');
		if (is_array($argues)) {
			$reflectionObj =& new ReflectionClass($class);      
			return $reflectionObj->newInstanceArgs($argues);
		}
		else {
			return new $class();
		}
	}
}

class Template {
	private $registry;
	private $dir = "templates/bt/";
	private $vars = array();
	private $css = array();
	private $js = array();
	private $script = array();
	private $title = "Default Title";
	private $description = "Default Description";
	private $keywords = "Default Keywords";
	//private $joomlaHead = "";
	private $head;
	private $template;

	private $view;

	function __construct($registry) {
		$this->registry = $registry;
	}

	public function __set($index, $value) {
		switch($index) {
			case "css": 
				if (file_exists(__SITE_PATH.'/'.$this->dir.$value)) 
				$this->css[] = "\t".'<link href="'.$this->dir.$value.'" rel="stylesheet" type="text/css" />'."\n"; 
			break;
			case "js": 
				if (file_exists(__SITE_PATH.'/'.$this->dir.$value)) 
				$this->js[] = "\t".'<script src="'.$this->dir.$value.'" type="text/javascript"></script>'."\n"; 
			break;
			case "title": $this->title = $value;  break;
			case "description": $this->description = $value;  break;
			case "keywords": $this->keywords = $value; break;
			default: 
				$this->vars[$index] = $value; 
			break;
		}
	}
	
	public function setTemplate($dir) {
		$this->dir = 'templates/'.$dir.'/';
	}
	
	public function loadTemplate() {
		$xml = simplexml_load_file($this->dir.'template.xml'); 
		foreach ($xml->file as $file) {
			switch($file->attributes()->type) {
				case "css": 
					if (file_exists(__SITE_PATH.'/'.$this->dir.$file->attributes()->src)) 
					$this->css[] =  "\t".'<link href="'.$this->dir.$file->attributes()->src.'" rel="stylesheet" type="text/css" />'."\n";; 
				break;
				case "js": 
					if (file_exists(__SITE_PATH.'/'.$this->dir.$file->attributes()->src)) 
					$this->js[] = "\t".'<script src="'.$this->dir.$file->attributes()->src.'" type="text/javascript"></script>'."\n"; 
				break;
				case "template":
					ob_start();
					include (__SITE_PATH.'/'.$this->dir.$file->attributes()->src);
					$this->template = ob_get_contents(); 
					ob_end_clean();
				break;
			}
		}
		$this->getTitle();
		$this->getDescription();
		$this->getKeywords();
		$this->getCSS();
		$this->getJS();
		//$this->joomlaHead();
	}
	
	/*
	public function loadJoomlaHead($head) {
		$this->joomlaHead =& $head;
	}
	
	private function joomlaHead() {
		$document =& JFactory::getDocument();
		$this->joomlaHead =& $document->getHeadData();
		if ($this->joomlaHead != "") {
			foreach ($this->joomlaHead['scripts'] as $key => $value) { 
				$key = str_replace(__SITE_FOLDER,"",$key);
				$this->head .= "\t".'<script src="'.$key.'" type="text/javascript"></script>'."\n";  
			}
			foreach ($this->joomlaHead['script'] as $key => $value) { 
				$value = str_replace(__SITE_FOLDER,'',$value);
				//$value = str_replace('site_url: "/joomla/siteadmin/",','site_url: "/joomla/",',$value);
				$this->head .= "\t".'<script language="javascript" type="text/javascript">'.$value.'</script>'."\n"; 
			}
			foreach ($this->joomlaHead['custom'] as $key => $value) {
				//echo $key; 
				$value = str_replace(__SITE_FOLDER,"",$value);
				$this->head .= "\t".$value."\n"; 
			}
		}
	}
	*/
	private function getCSS() {
		foreach ($this->css as $key => $value) { $this->head .= $value; }
	}
	
	private function getJS() {
		foreach ($this->js as $key => $value) { $this->head .= $value; }
	}
	
	private function getTitle() {
		$this->head .= "\t".'<title>'.$this->title.'</title>'."\n"; 
	}
	
	private function getDescription() {
		$this->head .= "\t".'<meta name="Description" content="'.$this->description.'"/>'."\n"; 
	}
	
	private function getKeywords() {
		$this->head .= "\t".'<meta name="keywords" content="'.$this->keywords.'"/>'."\n"; 
	}

	function show($name) {
		if ($this->registry->router->controller == "error404") {
			$this->setTemplate("error");
		}
		$this->loadTemplate();
		$path = __SITE_PATH . '/views'.'/'.$this->registry->router->controller.'/' . $name . '.html.php';
		if (file_exists($path) == false) {
			throw new Exception('Template not found in '. $path);
			return false;
		}
		foreach ($this->vars as $key => $value) {
			$$key = $value;
		}
		ob_start();
		include ($path);
		$this->view = ob_get_contents(); 
		ob_end_clean();
		/*$session =& JFactory::getSession();
		if ($session->get('application.message') != "") {
			$msg = '<div class="systemMsg">'.$session->get('application.message').'</div>';
			$this->template = str_replace("<jlite:message />",$msg,$this->template);
			$session->clear('application.message');
		}
		else {*/
		$this->template = str_replace("<jlite:message />","",$this->template);
		//}
		$menu = new Navigation();
		$this->template = str_replace("<jlite:menu />",$menu->output,$this->template);
		$this->template = str_replace("<jlite:head />",$this->head,$this->template);
		$this->template = str_replace("<jlite:main />",$this->view,$this->template);
		
		echo $this->template;      
	}
}

class Navigation {
	var $items = array();
	var $labels = array();
	var $output = "";
	
	function Navigation() {
		$this->addItem("?","Home");
		$this->addItem("?section=pages","Website Manager");
		$this->addItem("?section=google","Site Performance");
		$this->addItem("?section=contact","Contact Manager");
		$this->addItem("https://managemywebsite.archant.co.uk/OS4/","Email Manager");
		$this->buildMenu();
	}
	
	private function addItem($item,$label) {
		$this->items[] = $item;
		$this->labels[] = $label;
	}
	
	private function buildMenu() {
		/*$selected = JRequest::getVar("section","");
		for ($i=0;$i < count($this->items); $i++) {
			if (str_replace("?section=","",$this->items[$i]) == $selected || $selected == "") {
				$this->output .= '<a href="'.$this->items[$i].'" class="buttonSelected"><strong>'.$this->labels[$i].'</strong></a>';
				$selected = md5("ACTIVE-ITEM-SET");
			}
			else {
				$this->output .= '<a href="'.$this->items[$i].'" class="button"><strong>'.$this->labels[$i].'</strong></a>';
			}
		}*/
	}
	
}


$registry = new registry;

?>
